==> haskell-doctemplates-0.2.2.1-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-BPaiPV2QZKa4pD92tMHTqJ
key: doctemplates-0.2.2.1-BPaiPV2QZKa4pD92tMHTqJ
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: dff9bb796604c1ddad5a2d0beb732817
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-BPaiPV2QZKa4pD92tMHTqJ
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.2.2.1-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.2.2.1
id: doctemplates-0.2.2.1-JK9kOv0lpIhELtXNreBwms
key: doctemplates-0.2.2.1-JK9kOv0lpIhELtXNreBwms
license: BSD-3-Clause
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    A simple text templating system used by pandoc.
category: Text
abi: 73a1cd609aaadf37954ec4d336193827
exposed: True
exposed-modules:
    Text.DocTemplates
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctemplates-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-doctemplates
hs-libraries: HSdoctemplates-0.2.2.1-JK9kOv0lpIhELtXNreBwms
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
